
"""
redset
---------

Simple redis-backed, distributed sorted sets.

"""

__version__ = '0.5'

from redset.sets import *
